import * as dms from 'aws-cdk-lib/aws-dms';
import { Construct } from 'constructs';
import { ReplicationTypes, TableMappings, TaskSettings } from './core';
import { MySqlEndpoint, MySqlSettings } from './endpoints';
export interface MySql2MySqlProps {
    /**
       * The name of the source database
       */
    readonly sourceDatabaseName: string;
    /**
       * The settings for the source database
       */
    readonly sourceEndpointSettings: MySqlSettings;
    /**
       * The name of the target database
       */
    readonly targetDatabaseName: string;
    /**
       * The settings for the target database
       */
    readonly targetEndpointSettings: MySqlSettings;
    /**
       * The replication instance class to use
       * @default dms.t2.small
       */
    readonly replicationInstanceClass?: string;
    /**
       * The table mappings to be used for the replication.
       */
    readonly tableMappings: TableMappings;
    /**
       * Optional JSON settings for AWS DMS Serverless replications.
       */
    readonly taskSettings?: TaskSettings;
    /**
       * Replication Instance created in the State Stack
       */
    readonly replicationInstance: dms.CfnReplicationInstance;
    readonly replicationSettings?: any;
    readonly computeConfig?: dms.CfnReplicationConfig.ComputeConfigProperty;
    readonly replicationConfigIdentifier: string;
    readonly replicationType: ReplicationTypes;
}
export declare class MySql2MySql extends Construct {
    source: MySqlEndpoint;
    target: MySqlEndpoint;
    constructor(scope: Construct, id: string, props: MySql2MySqlProps);
}
